@@ -37,7 +37,7 @@ use strict;
 
 use vars qw ( $AUTOLOAD );
 
-$Net::Blogger::Engine::Base::VERSION        = 0.1.3;
+$Net::Blogger::Engine::Base::VERSION        = '0.3';
 @Net::Blogger::Engine::Base::ISA            = qw ( Exporter Net::Blogger::API::Core Net::Blogger::API::Extended );
 @Net::Blogger::Engine::Base::ISA::EXPORT    = qw ();
 @Net::Blogger::Engine::Base::ISA::EXPORT_OK = qw ();
@@ -46,7 +46,7 @@ use Carp;
 use Error;
 use Exporter;
 
-use XMLRPC::Lite;
+use SOAP::Lite;
 
 use Net::Blogger::API::Core;
 use Net::Blogger::API::Extended;
@@ -91,7 +91,7 @@ String. A valid password for the username/blogid pair.
 
 sub new {
     my $pkg = shift;
-    
+
     my $self = {};
     bless $self,$pkg;
 
@@ -112,6 +112,9 @@ sub init {
     $self->{'debug'}   = $args->{'debug'};
     $self->{"_posts"}  = [];
 
+    (my $caller = (caller(2))[3]) =~ /(.*)::([^::]+)::([^::]+)$/;
+    $self->{'__parent'} = $2;
+
     return 1;
 }
 
@@ -176,34 +179,58 @@ sub LastError {
     return $e;
 }
 
+sub Transport {
+  return "XMLRPC";
+}
+
 =head1 PRIVATE METHODS
 
 =cut
 
 =head2 $pkg->_Client()
 
-Return an XML-RPC client object.
+Return an XML-RPC or SOAP client object.
 
 =cut
 
 sub _Client {
     my $self = shift;
 
-    if (ref($self->{"_xmlrpc"}) ne "XMLRPC::Lite") {
-      my $client = XMLRPC::Lite->new()
+    unless (ref($self->{"_client"}) =~ /^(XMLRPC|SOAP)::Lite$/) {
+
+      my $pkg = uc $self->Transport();
+
+      if ($pkg =~ /^(XMLRPC|SOAP)$/) {
+	$pkg = join("::",$pkg,"Lite");
+      } 
+
+      else {
+	die "Unknown transport : '$pkg'\n";
+	$self->LastError("Unknown transport : $pkg");
+	return undef;
+      }
+
+      eval "require $pkg";
+
+      if ($@) {
+	die "Failed to eval, $@\n";
+      }
+      my $client = $pkg->new()
 	|| Error->throw(-text=>$!);
 
       $client->on_fault(\&_ClientFault);
       $client->proxy($self->Proxy); 
+      $client->uri($self->Uri());
 
+      # Fix this.
       if ($self->{'debug'}) {
 	$client->on_debug(sub { print @_; });
       }
 
-      $self->{"_xmlrpc"} = $client;
+      $self->{"_client"} = $client;
     }
 
-    return $self->{"_xmlrpc"};
+    return $self->{"_client"};
 }
 
 sub _ClientFault {
@@ -221,8 +248,14 @@ sub _ClientFault {
 =cut
 
 sub _Type {
-    my $self = shift;
-    return XMLRPC::Data->type(@_);
+  my $self = shift;
+  my $name = shift;
+
+  if ($name =~ /^(hash|array)$/) {
+    return SOAP::Data->name(args=>@_);
+  }
+
+  return SOAP::Data->type($name,@_);
 }
 
 sub DESTROY {
@@ -238,7 +271,7 @@ sub AUTOLOAD {
 	return undef;
     }
 
-    unless ($AUTOLOAD =~ /^(Proxy|AppKey|BlogId|Username|Password)$/) {
+    unless ($AUTOLOAD =~ /^(Proxy|Uri|AppKey|BlogId|Username|Password)$/) {
 	$self->LastError("Unkown method '$AUTOLOAD' called. Skipping.");
 	return undef;
     }
@@ -246,11 +279,24 @@ sub AUTOLOAD {
     my $property = lc "_".$AUTOLOAD;
 
     if (my $arg = shift) { 
-	$self->{ $property } = $arg; 
+      $self->{ $property } = $arg; 
+      
+      if (exists $self->{'__meta'}) {
+	$self->{'__meta'}->$property($arg);
+      }
+      
+      if (exists $self->{'__mt'}) {
+	$self->{'__mt'}->$property($arg);
+      }
+      
+      if (exists $self->{'__slash'}) {
+	$self->{'__slash'}->$property($arg);
+      }
+
     }
    
     if ($AUTOLOAD eq "Proxy") {
-	$self->{"_xmlrpc"} = undef;
+	$self->{"_client"} = undef;
     }
 
     return $self->{ $property };
@@ -258,11 +304,11 @@ sub AUTOLOAD {
 
 =head1 VERSION
 
-0.1.3
+0.3
 
 =head1 DATE
 
-April 15, 2002
+May 16, 2002
 
 =head1 AUTHOR
 
@@ -278,6 +324,38 @@ L<SOAP::Lite>
 
 =head1 CHANGES
 
+=head2 0.3
+
+=over
+
+=item * 
+
+Switched to SOAP::Lite rather than XMLRPC::Lite
+
+=item *
+
+Added I<Transport> and I<Uri>
+
+=back
+
+=head2 0.2
+
+=over
+
+=item *
+
+Added hooks to set child API (metaWeblog,mt) login data when parent object changes.
+
+=item *
+
+Modified I<_Type> to handle hash references.
+
+=item *
+
+Added quotes to I<$VERSION>
+
+=back
+
 =head2 0.1.3
 
 =over
